==> tmaid-2.4.7.tar.gz: tmaid-2.4.7/src/icons.h <==
/*
    Text maid
    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __ICONS_H__
#define __ICONS_H__


#include "tmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/******************************************************************************
*                                                                             *
* ja:アイコン                                                                 *
*                                                                             *
******************************************************************************/
extern const gchar *tmaid16_xpm[];
extern const gchar *tmaid24_xpm[];
extern const gchar *tmaid32_xpm[];
extern const gchar *tmaid48_xpm[];
extern const gchar *return16_xpm[];
extern const gchar *return24_xpm[];
extern const gchar *tab16_xpm[];
extern const gchar *tab24_xpm[];
extern const gchar *character16_xpm[];
extern const gchar *character24_xpm[];
#if ! GTK_CHECK_VERSION(2,10,0)
extern const gchar *select_all16_xpm[];
extern const gchar *select_all24_xpm[];
#endif /* not GTK_CHECK_VERSION(2,10,0) */
extern const gchar *next16_xpm[];
extern const gchar *next24_xpm[];
extern const gchar *previous16_xpm[];
extern const gchar *previous24_xpm[];
extern const gchar *filetype16_xpm[];
extern const gchar *filetype24_xpm[];
#if ! GTK_CHECK_VERSION(2,6,0)
extern const gchar *about16_xpm[];
extern const gchar *about24_xpm[];
#endif /* not GTK_CHECK_VERSION(2,6,0) */


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __ICONS_H__ */

==> tmaid-2.6.8.tar.gz: tmaid-2.6.8/src/icons.h <==
/*
    Text maid
    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __ICONS_H__
#define __ICONS_H__


#include "tmaid.h"


G_BEGIN_DECLS


/******************************************************************************
*                                                                             *
* ja:アイコン                                                                 *
*                                                                             *
******************************************************************************/
extern const gchar *tmaid16_xpm[];
extern const gchar *tmaid24_xpm[];
extern const gchar *tmaid32_xpm[];
extern const gchar *tmaid48_xpm[];
extern const gchar *return16_xpm[];
extern const gchar *return24_xpm[];
extern const gchar *tab16_xpm[];
extern const gchar *tab24_xpm[];
extern const gchar *character16_xpm[];
extern const gchar *character24_xpm[];
#if ! GTK_CHECK_VERSION(2,10,0)
extern const gchar *select_all16_xpm[];
extern const gchar *select_all24_xpm[];
#endif /* not GTK_CHECK_VERSION(2,10,0) */
extern const gchar *next16_xpm[];
extern const gchar *next24_xpm[];
extern const gchar *previous16_xpm[];
extern const gchar *previous24_xpm[];
extern const gchar *filetype16_xpm[];
extern const gchar *filetype24_xpm[];
#if ! GTK_CHECK_VERSION(2,6,0)
extern const gchar *about16_xpm[];
extern const gchar *about24_xpm[];
#endif /* not GTK_CHECK_VERSION(2,6,0) */


G_END_DECLS


#endif /* __ICONS_H__ */
